ConfluenceClient

Struct ConfluenceClient 

pub struct ConfluenceClient { /* private fields */ }

Implementations

Source

impl ConfluenceClient

pub fn new(base_url: impl Into<String>, auth: ConfluenceAuth) -> Self

pub fn with_http_client(self, http: Client) -> Self

pub fn base_url(&self) -> &str

pub fn auth(&self) -> &ConfluenceAuth

pub fn with_api_version(self, api_version: Option<&str>) -> Self

pub fn with_proxy(self, headers: HashMap<String, String>) -> Self

Configure proxy mode with headers added to every request. When proxy is active, provider auth headers are suppressed.

pub fn rest_api_url(&self, path: &str) -> String

pub async fn get_json<T>(&self, path: &str) -> Result<T>

pub async fn post_json<T, B>(&self, path: &str, body: &B) -> Result<T>

pub async fn put_json<T, B>(&self, path: &str, body: &B) -> Result<T>

pub async fn post_empty_json<B>(&self, path: &str, body: &B) -> Result<()>
where B: Serialize + ?Sized,

pub async fn delete_empty(&self, path: &str) -> Result<()>